#
# spec file for package pptpd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pptpd
Version:        1.4.0
Release:        5.3
Summary:        PoPToP - PPTP Daemon, Linux as Microsoft VPN Server
License:        GPL-2.0-or-later
Group:          Productivity/Networking/PPP
URL:            https://www.poptop.org/
Source:         https://downloads.sourceforge.net/project/poptop/pptpd/pptpd-%{version}/pptpd-%{version}.tar.gz
Source3:        pptp-install.tar.bz2
Source4:        pptpd.conf
Source5:        options.ppp0
Source7:        README.SUSE
Source9:        pptpd.service
Patch0:         makefile.diff
Patch1:         pptpd-cflags.patch
Patch2:         ppp-2.5.0.patch
Patch3:         pptpd-stringcompare.patch
Patch4:         bcrelay-iflog-size-limit.patch
Patch5:         gcc-14-fix.patch
BuildRequires:  automake
BuildRequires:  pkgconfig
BuildRequires:  ppp-devel
BuildRequires:  pkgconfig(udev)
Requires:       ppp
%{?systemd_ordering}

%description
PoPToP is a PPTP(Point-to-Point Tunneling Protocol) server solution for
Linux, it allows Linux servers to function seamlessly in the PPTP VPN
environment. This release supports Windows 95/98/NT/2000 PPTP clients
and PPTP Linux clients.

%prep
%setup -q -a 3
%patch -P 0
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3
%patch -P 4 -p1
%patch -P 5 -p1
rm plugins/patchlevel.h
cp -p %{SOURCE5} %{SOURCE7} .

%build
autoreconf -i -f
%configure
%make_build OPTFLAGS="%{optflags}"

%install
%make_install
install -m 0755 pptpd			%{buildroot}%{_sbindir}/pptpd
install -m 0755 pptpctrl		%{buildroot}%{_sbindir}/pptpctrl

install -D -m 0644 %{SOURCE9} %{buildroot}%{_unitdir}/`basename %{SOURCE9}`
mkdir -p %{buildroot}%{_modulesloaddir}
echo "ppp_mppe" > %{buildroot}%{_prefix}/lib/modules-load.d/pptpd.conf
install -Dm 0644 %{SOURCE4}			%{buildroot}%{_sysconfdir}/pptpd.conf
find {samples,PPTP-Installation,pptp-server} -type f -exec chmod -x {} +
chmod -x AUTHORS COPYING ChangeLog INSTALL NEWS README* TODO

%pre
%service_add_pre %{name}.service

%preun
%service_del_preun %{name}.service

%post
%service_add_post %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license COPYING
%doc README.SUSE options.ppp0
%doc ChangeLog NEWS README* TODO
%doc samples PPTP-Installation pptp-server
%config %{_sysconfdir}/pptpd.conf
%{_mandir}/*/pptp*
%{_mandir}/man8/bcrelay.8%{?ext_man}
%{_sbindir}/pptpctrl
%{_sbindir}/pptpd
%{_sbindir}/bcrelay
%{_prefix}/lib/pptpd
%{_unitdir}/%{name}.service
%{_modulesloaddir}/pptpd.conf

%changelog
* Wed Feb  7 2024 Dirk Müller <dmueller@suse.com>
- drop LIESMICH.SUSE, rcpptpd: only for non-systemd distros
- remove ifconditions for systemd, all maintained distros
  have it by now
- add bcrelay-iflog-size-limit.patch, gcc-14-fix.patch,
  ppp-2.5.0.patch to fix build in TW
* Fri Apr 22 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%_modulesloaddir instead of hardcoding
  usr/lib/modules-load.d.
- BuildRequire pkgconfig(udev) instead of pkgconfig(systemd):
  modules-load.d belongs to udev, not systemd.
* Wed Oct 20 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * pptpd.service
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Thu Mar 12 2015 p.drouand@gmail.com
- Update to version 1.4.0
  * change GPL license FSF addresses
  * clean up unused return value warnings
  * don't leak memory on duplicate packet
  * clean up several compiler warnings
  * use pppd.h from ppp  *dev
  * do not drop connection on ENOBUFS
  * fix binary trash when launching pppd
  * add remotenumber support
  * catch missing EOL at EOF
  * add bcrelay manual page
  * fix segfault on invalid IP range
  * add support for VRFs through libvrf
  * fix implementation of IDLE_WAIT
  * fix compilation with uclibc with legacy support disabled
  * avoid ipparam and logwtmp on BSD
  * compiler fix for pptp_gre_header
  * suppress "ignored a SET LINK INFO packet with real ACCMs"
  * add missing logwtmp option on pptpd.conf manyal page
  * fix reordering some more
- Do not provide a sysvinit script on a system which support
  systemd; it's redundant
- Remove pptpd-pptpd-logwtmp-version.patch; fixed on upstream release
- Remove depreciated AUTHORS section
- Update pptpd-stringcompare.patch
* Wed Aug  6 2014 vwallfahrer@suse.com
- Changed file names README.SUSE and LIESMICH.SUSE, because it is
  the right SUSE spelling (bnc#889011).
* Tue Dec 20 2011 crrodriguez@opensuse.org
- Add native systemd units
* Mon Dec 19 2011 coolo@suse.com
- use original tarball
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Fri Sep 12 2008 hvogel@suse.de
- Fixed README errors [bnc#414109]
* Thu Aug 28 2008 cthiel@suse.de
- fix init script
* Fri Aug  1 2008 crrodriguez@suse.de
-  pptpd is useless without ppp [BNC#414103]
* Sat Jul  5 2008 crrodriguez@suse.de
- fix build
* Thu Feb 21 2008 crrodriguez@suse.de
- add missing remote_fs dependency to init script
- add missing calls to restart_on_update and stop_on_removal macros
* Sun Jun 17 2007 ro@suse.de
- avoid string compare with char literal
* Fri May  4 2007 hvogel@suse.de
- update to version 1.3.4
  * fixes two packet reordering bugs
  * turn off echo on the slave pty
  * Deprecate PPP_WAIT.
  * fix segfault on -C option
* Mon Oct 23 2006 hvogel@suse.de
- fix logwtmp plugin version. Use ppp devel files in the
  future. [#209908]
* Thu Jul 13 2006 mskibbe@suse.de
- update to version 1.3.0 which
  o disable Van Jacobson compression
  o packet reordering implementation, contributed from
    PPTP Client anonymously
  o fix some bugs
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Nov  3 2005 arvin@suse.de
- updated to version 1.2.3 with some minor bug fixes and
  performance enhancements
* Wed Sep 28 2005 meissner@suse.de
- use RPM_OPT_FLAGS.
* Tue Apr 26 2005 arvin@suse.de
- updated to version 1.2.1
* Wed Jan 26 2005 meissner@suse.de
- use RPM_OPT_FLAGS
* Sat Jan 10 2004 adrian@suse.de
- fix user build
* Wed Nov 26 2003 bk@suse.de
- rcpptpd: add the options -sq to startproc to detach(fixes #27385)
* Sun Jun  1 2003 ro@suse.de
- fix rcpptpd symlink
* Mon May 12 2003 bk@suse.de
- fix pptp daemon buffer overflow with controlpacket length(#26508)
* Tue Sep 17 2002 ro@suse.de
- replaced "network route" by "$network" in rcscript(fix bug #21312)
* Tue Aug 20 2002 mmj@suse.de
- Correct PreReq
* Thu Feb 14 2002 arvin@suse.de
- updated and fixed README
- use BuiltRoot
* Tue Jan 15 2002 egmont@suselinux.hu
- removed colons from startup/shutdown messages
* Tue Jan 15 2002 ro@suse.de
- removed START_PPTPD
* Tue Aug  7 2001 arvin@suse.de
- LSB conform init script (bug #9075)
* Tue Nov 28 2000 arvin@suse.de
- use insserv in post-install for creating init.d scripts
- changed group tag
* Wed Nov 22 2000 bk@suse.de
- Updated to version 1.1.2, needed for the firew-livecd with win2k.
- added man pages
* Wed Mar  8 2000 dipa@suse.de
- added pptp-install.tar.gz, pptpd.conf and options.ppp0
* Mon Mar  6 2000 bk@suse.de
- added README.SuSE and LIESMICH.SuSE from jnschei.
- wrote and added start script rcpptpd
* Wed Feb 23 2000 dipa@suse.de
- pptpd is a new package to include linux servers in PPTP
  established VPNs. It based on release version pptp-1.0.0.tgz
